@@ -1,4 +1,4 @@
-/* $Id: procsegment.h,v 1.14 1999/02/23 11:43:09 martin Exp $ */
+/* $Id: procsegment.h,v 1.26 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_PROC_SEGMENT_TEXT_RSS		0
 #define GLIBTOP_PROC_SEGMENT_SHLIB_RSS		1
@@ -46,7 +46,7 @@ typedef struct _glibtop_proc_segment	glibtop_proc_segment;
 
 struct _glibtop_proc_segment
 {
-	u_int64_t	flags,
+	guint64	flags,
 		text_rss,	/* text resident set size */
 		shlib_rss,	/* shared-lib resident set size */
 		data_rss,	/* data resident set size */
@@ -58,7 +58,7 @@ struct _glibtop_proc_segment
 		start_stack;	/* address of the bottom of stack segment */
 };
 
-#define glibtop_get_proc_segment(p1, p2)	glibtop_get_proc_segment_l(glibtop_global_server, p1, p2)
+void glibtop_get_proc_segment(glibtop_proc_segment *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_SEGMENT
 #define glibtop_get_proc_segment_r	glibtop_get_proc_segment_p
@@ -76,17 +76,7 @@ void glibtop_init_proc_segment_s (glibtop *server);
 void glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
 
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_segment [];
-extern const unsigned glibtop_types_proc_segment [];
-extern const char *glibtop_labels_proc_segment [];
-extern const char *glibtop_descriptions_proc_segment [];
-
-#endif
-
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
