@@ -1,4 +1,4 @@
-/* $Id: procargs.c,v 1.19 2003/10/20 15:19:50 hadess Exp $ */
+/* $Id: procargs.c,v 1.22 2004/06/09 18:52:21 bdejean Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -50,7 +50,7 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 {
 	struct kinfo_proc *pinfo;
 	char *retval, **args, **ptr;
-	unsigned size = 0, pos = 0;
+	size_t size = 0, pos = 0;
 	int count;
 
 #ifndef __bsdi__
@@ -59,7 +59,7 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 #endif
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_ARGS), 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_proc_args));
 
 	/* swapper, init, pagedaemon, vmdaemon, update - this doen't work. */
@@ -93,11 +93,10 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 		size += strlen (*ptr)+1;
 
 	size += 2;
-	retval = g_malloc (server, size);
-	memset (retval, 0, size);
+	retval = g_malloc0 (size);
 
 	for (ptr = args; *ptr; ptr++) {
-		int len = strlen (*ptr)+1;
+		const size_t len = strlen (*ptr)+1;
 		memcpy (retval+pos, *ptr, len);
 		pos += len;
 	}
