@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: glibtop_server.h,v 1.8 2003/10/20 15:20:08 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,7 +24,7 @@
 #ifndef __GLIBTOP_SERVER_H__
 #define __GLIBTOP_SERVER_H__
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_SUID_CPU		0
 #define GLIBTOP_SUID_MEM		0
@@ -46,11 +44,9 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_SUID_PROC_SEGMENT	0
 #define GLIBTOP_SUID_PROC_ARGS		0
 #define GLIBTOP_SUID_PROC_MAP		0
-#define GLIBTOP_SUID_NETINFO		0
 #define GLIBTOP_SUID_NETLOAD		0
-#define GLIBTOP_SUID_INTERFACE_NAMES	0
 #define GLIBTOP_SUID_PPP		0
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
