@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: loadavg.c,v 1.12 2004/10/11 18:01:25 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -39,53 +37,57 @@ static const unsigned long _glibtop_sysdeps_loadavg =
 
 /* Init function. */
 
-int
+void
 glibtop_init_loadavg_s (glibtop *server)
 {
-    server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
-
-    return 0;
+	server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
 }
 
 /* Provides load average. */
 
-int
+void
 glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf)
 {
 #ifndef HAVE_GETLOADAVG
-    kstat_ctl_t *kc;
-    kstat_t *ksp;
-    int i;
-    static char *avestrings[] = { "avenrun_1min",
-				  "avenrun_5min",
-				  "avenrun_15min" };
+	kstat_ctl_t *kc;
+	kstat_t *ksp;
+	size_t i;
+	static const char avestrings[][14] = { "avenrun_1min",
+					       "avenrun_5min",
+					       "avenrun_15min" };
 #endif
-    memset (buf, 0, sizeof (glibtop_loadavg));
+	memset (buf, 0, sizeof (glibtop_loadavg));
 
 #ifdef HAVE_GETLOADAVG
-    if (getloadavg (buf->loadavg, 3) < 0)
-	return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
+	if (getloadavg (buf->loadavg, 3) != 3)
+		return;
+
 #else
-    if(!(kc = server->_priv->machine.kc))
-	return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
-    switch(kstat_chain_update(kc)) {
-    case -1: assert(0); /* Debugging, shouldn't happen */
-    case 0:  break;
-    default: glibtop_get_kstats(server);
-    }
-    if(!(ksp = server->_priv->machine.system))
-	return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
-    if(kstat_read(kc, ksp, NULL) < 0)
-	return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
-    for(i = 0; i < 3; ++i) { /* Do we have a countof macro? */
-	kstat_named_t *kn;
+	if(!(kc = server->machine.kc))
+	    return;
 
-	kn = (kstat_named_t *)kstat_data_lookup(ksp, avestrings[i]);
-	if(kn)
-	    buf->loadavg[i] = (double)kn->value.ul / FSCALE;
-    }
-#endif
-    buf->flags = _glibtop_sysdeps_loadavg;
+	switch(kstat_chain_update(kc))
+	{
+	    case -1: assert(0); /* Debugging, shouldn't happen */
+	    case 0:  break;
+	    default: glibtop_get_kstats(server);
+	}
 
-    return 0;
+	if(!(ksp = server->machine.system))
+	    return;
+
+	if(kstat_read(kc, ksp, NULL) < 0)
+	    return;
+
+	for(i = 0; i < 3; ++i) /* Do we have a countof macro? */
+	{
+		kstat_named_t *kn;
+
+		kn = (kstat_named_t *)kstat_data_lookup(ksp, avestrings[i]);
+		if(kn)
+		    buf->loadavg[i] = (double)kn->value.ul / FSCALE;
+	}
+#endif /* HAVE_GETLOADAVG */
+
+	buf->flags = _glibtop_sysdeps_loadavg;
 }
